@@ -18,7 +18,10 @@ sub dc_debconf_select (){
     my @choices = ();
     foreach (split (/\s*,\s*/, $pkgowners)){
 	my $entry = metaget ("$_/languages", "default");
-	$entry =~ s/\s*(.*)\s*/$1/;
+	for ( $entry ){ # trim leading/trailing whitespaces the perlfaq way
+	    s/^\s+//;
+	    s/\s+$//;
+	}
 	push (@choices, split(/\s*,\s*/, $entry));
     }
     my $choices = join (', ', sort {lc $a cmp lc $b} @choices);
